@@ -18,7 +18,7 @@ package PkgConfig::UDefs;
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.07420';
+our $VERSION = '0.07620';
 
 require 5.006;
 
@@ -28,9 +28,10 @@ use Config;
 use File::Spec;
 use File::Glob 'bsd_glob';
 use Class::Struct; #in core since 5.004
-our $UseDebugging;
-
 use Data::Dumper;
+use File::Basename qw( dirname );
+
+our $UseDebugging;
 
 ################################################################################
 ### Check for Log::Fu                                                        ###
@@ -65,7 +66,11 @@ our @DEFAULT_SEARCH_PATH = qw(
 
 );
 
-if($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
+if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
+
+    # use the defaults regardless of detected platform
+
+} elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
     if(-x "/usr/bin/dpkg-architecture") {
         my $arch = `/usr/bin/dpkg-architecture -qDEB_HOST_MULTIARCH`;
         chomp $arch;
@@ -146,10 +151,12 @@ if($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
     require Config;
     if($Config::Config{myuname} =~ /strawberry-perl/)
     {
-        my($vol, $dir, $file) = File::Spec->splitpath($INC{"Config.pm"});
+        my($vol, $dir, $file) = File::Spec->splitpath($^X);
         my @dirs = File::Spec->splitdir($dir);
         splice @dirs, -3;
-        @DEFAULT_SEARCH_PATH = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
+        my $path = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
+        $path =~ s{\\}{/}g;
+        @DEFAULT_SEARCH_PATH = $path;
     }
 
 }
@@ -168,6 +175,53 @@ our @DEFAULT_EXCLUDE_LFLAGS = qw(
     -R/lib -R/usr/lib -R/usr/lib64 -R/lib32 -R/lib64 -R/usr/local/lib
 );
 
+if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
+
+    # use the defaults regardless of detected platform
+
+} elsif($^O eq 'MSWin32') {
+
+    if($Config::Config{cc} =~ /cl(\.exe)?$/i)
+    {
+        @DEFAULT_EXCLUDE_LFLAGS = ();
+        @DEFAULT_EXCLUDE_CFLAGS = ();
+    }
+    else
+    {
+        @DEFAULT_EXCLUDE_LFLAGS = (
+            "-L/mingw/lib",
+            "-R/mingw/lib",
+            "-L/mingw/lib/pkgconfig/../../lib",
+            "-R/mingw/lib/pkgconfig/../../lib",
+        );
+        @DEFAULT_EXCLUDE_CFLAGS = (
+            "-I/mingw/include",
+            "-I/mingw/lib/pkgconfig/../../include",
+        );
+    }
+    
+    # See caveats above for Strawberry
+    require Config;
+    if($Config::Config{myuname} =~ /strawberry-perl/)
+    {
+        my($vol, $dir, $file) = File::Spec->splitpath($^X);
+        my @dirs = File::Spec->splitdir($dir);
+        splice @dirs, -3;
+        my $path = (File::Spec->catdir($vol, @dirs, qw( c )));
+        $path =~ s{\\}{/}g;
+        push @DEFAULT_EXCLUDE_LFLAGS, (
+            "-L$path/lib",
+            "-L$path/lib/pkgconfig/../../lib",
+            "-R$path/lib",
+            "-R$path/lib/pkgconfig/../../lib",
+        );
+        push @DEFAULT_EXCLUDE_CFLAGS, (
+            "-I$path/include",
+            "-I$path/lib/pkgconfig/../../include",
+        );
+    }
+}
+
 
 my $LD_OUTPUT_RE = qr/
     SEARCH_DIR\("
@@ -565,7 +619,10 @@ sub parse_pcfile {
     
     #Fold lines:
     
-    foreach my $line (@lines) {
+    my $pcfiledir = dirname $pcfile;
+    $pcfiledir =~ s{\\}{/}g;
+
+    foreach my $line ("pcfiledir=$pcfiledir", @lines) {
         $self->parse_line($line, \@eval_strings);
     }
     
@@ -1002,7 +1059,7 @@ __END__
 
 =head1 NAME
 
-PkgConfig - Pure-Perl Core-Only replacement for C<pkg-config>
+PkgConfig - Pure-Perl Core-Only replacement for pkg-config
 
 =head1 SYNOPSIS
 
@@ -1016,7 +1073,8 @@ PkgConfig - Pure-Perl Core-Only replacement for C<pkg-config>
     # -lgmodule-2.0 -ldl -lgthread-2.0 -pthread -lrt -lglib-2.0
 
 C<pkg-config.pl> can be used as an alias for C<ppkg-config> on platforms that
-support it.
+support it.  It can also be installed as C<pkg-config> though this is not
+recomended if your system has a native C<pkg-config>.
 
 Compare to:
     $ pkg-config --libs --cflags --static gio-2.0
@@ -1048,7 +1106,7 @@ This is not a description of the uses of C<pkg-config> but rather a description
 of the differences between the C version and the Perl one.
 
 While C<pkg-config> is a compiled binary linked with glib, the pure-perl version
-has no such requirement, and will run wherever Perl ( >= 5.04 ) does.
+has no such requirement, and will run wherever Perl ( >= 5.6 ) does.
 
 The main supported options are the common C<--libs>, C<--cflags>,
 C<--static>, C<--exists> and C<--modversion>.
@@ -1288,6 +1346,31 @@ Example, don't install any scripts:
 
  % perl Makefile.PL --script none
 
+=head2 CAVEATS
+
+On Strawberry Perl C<ppkg-config> acts like Strawberry is the system.  
+This means that
+
+=over 4
+
+=item
+
+The .pc files that are bundled with Strawberry are searched by default.
+
+=item
+
+The Strawberry include and lib directories are used to compute the 
+exclusion lists.
+
+=back
+
+As of Strawberry 5.20.0.1 PkgConfig is bundled with Strawberry and 
+C<pkg-config> is installed by default (in addition to C<ppkg-config>,
+though the C<ppkg-config> alias is NOT bundled with Strawberry itself).
+
+For details on how to patch the .pc files bundled with older Strawberries,
+see the C<README.win32> that comes with this Distribution.
+
 =head2 BUGS
 
 The order of the flags is not exactly matching to that of C<pkg-config>. From my
